package com.steerinfo.dil.feign;

import com.steerinfo.framework.controller.RESTfulResult;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/23 8:46
 * @Version:V2.0
 */
@FeignClient(value = "DIL-BMSTRUCK-API-DEV", url = "${openfeign.BmstruckFeign.url}")
public interface BmstruckFeign {

    /**
     * 展示汽运详单信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckdetailsorder/getTruckDetailsOrderList")
    RESTfulResult getTruckDetailsOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                           @RequestParam("pageNum") Integer pageNum,
                                           @RequestParam("pageSize") Integer pageSize,
                                           @RequestParam("apiId") Integer apiId,
                                           @RequestParam("orderType") Integer orderType,
                                           @RequestParam("con") String con);

    /**
     * 展示汽运实绩信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckdetailsorder/getTruckResultList")
    RESTfulResult getTruckResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                     @RequestParam("pageNum") Integer pageNum,
                                     @RequestParam("pageSize") Integer pageSize,
                                     @RequestParam("apiId") Integer apiId,
                                     @RequestParam("orderId") BigDecimal orderId);

    /**
     * 新增汽运详单
     *
     * @param orderId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckdetailsorder/addDetailsOrder/{orderId}")
    RESTfulResult addTruckDetailsOrder(@PathVariable("orderId") BigDecimal orderId);


    /**
     * 展示内转汽运未生成账单的作业详单信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckConverted/getUnFinishedConvertedTruckDetailsOrderList")
    RESTfulResult getUnFinishedConvertedTruckDetailsOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                              @RequestParam("pageNum") Integer pageNum,
                                                              @RequestParam("pageSize") Integer pageSize,
                                                              @RequestParam("apiId") Integer apiId,
                                                              @RequestParam("orderType") BigDecimal orderType);

    /**
     * 新增内转汽运详单
     *
     * @param orderId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckConverted/addConvertedDetailsOrder/{orderId}")
    RESTfulResult addConvertedDetailsOrder(@PathVariable("orderId") BigDecimal orderId);


    /**
     * 生成内转汽运账单
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckstatement/addConvertedTruckStatement")
    RESTfulResult addConvertedTruckStatement(@RequestBody(required = false) List<Map<String, Object>> mapList);

    /**
     * 删除汽运账单
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckstatement/deleteConvertedTruckStatement/{statementId}")
    RESTfulResult delete(@PathVariable("statementId") BigDecimal statementId);

    /**
     * 审批计费账单
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckstatement/updateConvertedTruckStatement/{statementId}")
    RESTfulResult update(@PathVariable("statementId") BigDecimal statementId);

    /**
     * 销售汽运计费账单
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckstatement/getTruckStatementList")
    RESTfulResult getTruckStatementList(@RequestBody(required = false) Map<String, Object> mapValue,
                                        @RequestParam("pageNum") Integer pageNum,
                                        @RequestParam("pageSize") Integer pageSize,
                                        @RequestParam("apiId") Integer apiId,
                                        @RequestParam("con") String con);

    /**
     * 生成销售汽运计费账单
     *
     * @param mapList
     * @return
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckstatement/addTruckStatement")
    RESTfulResult addTruckStatement(@RequestBody List<Map<String, Object>> mapList);

    /**
     * 展示账单下的详单
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @param statementId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckstatement/getSaleTruckStatementDetailsOrderList")
    RESTfulResult getSaleTruckStatementDetailsOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                        @RequestParam("pageNum") Integer pageNum,
                                                        @RequestParam("pageSize") Integer pageSize,
                                                        @RequestParam("apiId") Integer apiId,
                                                        @RequestParam("statementId") BigDecimal statementId,
                                                        @RequestParam("con") String con);

    /**
     * 审核
     *
     * @param statementId
     * @param status
     * @param person
     * @return
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckcheck/updateBmstruckCheck")
    RESTfulResult updateBmstruckCheck(@RequestParam("statementId") BigDecimal statementId,
                                      @RequestParam("status") Integer status,
                                      @RequestParam("person") Integer person);

    /**
     * 查询销售汽运离100KM差距10KM内计费公式
     *
     * @return
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckformulas/getSmallTruckFormula")
    RESTfulResult getSmallTruckFormula();

    /**
     * 查询销售汽运离100KM差距10KM外计费公式
     *
     * @return
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckformulas/getBigTruckFormula")
    RESTfulResult getBigTruckFormula();

    /**
     * 展示发票
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckinvoice/getInvoiceList")
    RESTfulResult getInvoiceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                 @RequestParam("pageNum") Integer pageNum,
                                 @RequestParam("pageSize") Integer pageSize,
                                 @RequestParam("apiId") Integer apiId,
                                 @RequestParam("con") String con);

    /**
     * 新增发票
     *
     * @param mapVal
     * @return
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckinvoice/addBmstruckInvoice")
    RESTfulResult addBmstruckInvoice(@RequestBody Map<String, Object> mapVal);

    /**
     * 展示汽运未生成账单的详单信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @param orderType
     * @return
     */
    @PostMapping(value = "/api/v1/bmstruck/bmstruckdetailsorder/getUnFinishedTruckDetailsOrderList")
    RESTfulResult getUnFinishedTruckDetailsOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                     @RequestParam("pageNum") Integer pageNum,
                                                     @RequestParam("pageSize") Integer pageSize,
                                                     @RequestParam("apiId") Integer apiId,
                                                     @RequestParam("orderType") Integer orderType,
                                                     @RequestParam("con") String con);
}